@@ -127,16 +127,16 @@ def key_events(stdscr, tree1, maxx):
     if key == curses.KEY_ENTER or key == 10 or key == 13:  # this is enter key
         if tree1.showtimer:
             if tree1.currentmenu == "timer":
-                tree1.starttimer(tree1.selectedtimer)
+                tree1.starttimer(tree1.selectedtimer, stdscr, maxx)
             else:
-                tree1.featureselect(tree1.selectedtimer)
+                tree1.featureselect(tree1.selectedtimer, maxx, stdscr)
             timerstart = vlc.MediaPlayer(str(RES_FOLDER / "timerstart.wav"))
             timerstart.play()
             tree1.showtimer = False
 
         if tree1.breakover:
             tree1.breakover = False
-            tree1.starttimer(tree1.selectedtimer)
+            tree1.starttimer(tree1.selectedtimer, stdscr, maxx)
             timerstart = vlc.MediaPlayer(str(RES_FOLDER / "timerstart.wav"))
             timerstart.play()
 
@@ -156,6 +156,7 @@ def key_events(stdscr, tree1, maxx):
             tree1.currentmenu = "feature"
 
         else:
+            tree1.radiomode = False
             tree1.music_list_num += 1
             if tree1.music_list_num > len(tree1.music_list) - 1:
                 tree1.music_list_num = len(tree1.music_list) - 1
@@ -170,6 +171,7 @@ def key_events(stdscr, tree1, maxx):
             tree1.selectedtimer = 0
             tree1.currentmenu = "timer"
         else:
+            tree1.radiomode = False
             tree1.music_list_num -= 1
             if tree1.music_list_num < 0:
                 tree1.music_list_num = 0
@@ -265,11 +267,15 @@ class tree:
             " POMODORO 20+10 ",
             " POMODORO 40+20 ",
             " POMODORO 50+10 ",
+            " CUSTOM TIMER ",
             " END TIMER NOW ",
         ]
         self.featurelist = [
             " PLAY MUSIC FROM YOUTUBE ",
-            " LOFI RADIO "
+            " LOFI RADIO 1 ",
+            " LOFI RADIO 2 ",
+            " LOFI RADIO 3 ",
+            " CUSTOM PLAYLIST "
         ]
         self.currentmenu = "timer"
         self.selectedtimer = 0
@@ -471,12 +477,57 @@ class tree:
         if self.istimer and int(time.time()) == int(self.workendtime):
             self.breakstart()
 
-    def starttimer(self, inputtime):
-        if inputtime >= 4:
+    def starttimer(self, inputtime, stdscr, maxx):
+        if inputtime == 5:
             self.breakendtext = "TIMER IS OVER, PRESS ENTER"
             self.worktime = 0
             self.breaktime = 0
             self.istimer == False
+        
+        elif inputtime == 4:
+
+            try:
+
+                curses.textpad.rectangle(stdscr, 0,0,2, maxx-1)
+                stdscr.addstr(1,1, "ENTER WORK LENGTH (min) : ")
+                stdscr.refresh()
+
+                curses.echo()
+                curses.nocbreak()
+                stdscr.nodelay(False)
+                stdscr.keypad(False)
+                curses.curs_set(1)
+
+                self.worktime = int(stdscr.getstr())*60
+
+                stdscr.addstr(1,1, " "*(maxx-2))
+                stdscr.addstr(1,1, "ENTER BREAK LENGTH (min) : ")
+                stdscr.refresh()
+
+                self.breaktime = int(stdscr.getstr())*60
+
+                curses.noecho()
+                curses.cbreak()
+                stdscr.nodelay(True)
+                stdscr.keypad(True)
+                curses.curs_set(0)
+
+                self.istimer = True
+
+            except ValueError:
+                curses.noecho()
+                curses.cbreak()
+                stdscr.nodelay(True)
+                stdscr.keypad(True)
+                curses.curs_set(0)
+
+                self.notifystring = "VALUE ERROR, PLEASE ENTER AN INTEGER"
+                self.notifyendtime = int(time.time())+5
+                self.isnotify = True
+
+                return 0
+
+
         else:
             self.breakendtext = "BREAK IS OVER, PRESS ENTER TO START NEW TIMER"
             self.istimer = True
@@ -485,14 +536,47 @@ class tree:
 
         self.workendtime = int(time.time()) + self.worktime
 
-    def featureselect(self, inputfeature):
+    def featureselect(self, inputfeature, maxx, stdscr):
         self.radiomode = False
         if inputfeature == 0:
+            if hasattr(self, "media"):
+                self.media.stop()
             self.youtubedisplay = True
         if inputfeature == 1:
             self.playlist = Playlist("https://www.youtube.com/playlist?list=PLOzDu-MXXLliO9fBNZOQTBDddoA3FzZUo")
             self.lofiradio()
 
+        if inputfeature == 2:
+            self.playlist = Playlist("https://www.youtube.com/playlist?list=PL0ONFXpPDe_mtm3ciwL-v7EE-7yLHDlP8")
+            self.lofiradio()
+
+        if inputfeature == 3:
+            self.playlist = Playlist("https://www.youtube.com/playlist?list=PLKYTmz7SemaqVDF6XJ15bv_8-j7ckkNgb")
+            self.lofiradio()
+
+        if inputfeature == 4:
+            curses.textpad.rectangle(stdscr, 0,0,2, maxx-1)
+            stdscr.addstr(1,1, "ENTER PLAyLIST LINK : ")
+            stdscr.refresh()
+
+            curses.echo()
+            curses.nocbreak()
+            stdscr.nodelay(False)
+            stdscr.keypad(False)
+            curses.curs_set(1)
+
+            templink = stdscr.getstr()
+            templink = str(templink)[1:][:-1]
+            self.playlist = Playlist(str(templink))
+
+            curses.noecho()
+            curses.cbreak()
+            stdscr.nodelay(True)
+            stdscr.keypad(True)
+            curses.curs_set(0)
+
+            self.lofiradio()
+
     def loading(self, stdscr, maxx):
             spinner = [
             "[    ]",
@@ -754,8 +838,13 @@ def main():
 
                 tree1.timer()
 
-                if not tree1.isloading and tree1.radiomode and round(tree1.media.get_position()*100) == 100:
-                    tree1.lofiradio()
+                if not tree1.isloading and round(tree1.media.get_position()*100) == 100:
+                    if tree1.radiomode:
+                        tree1.lofiradio()
+                    else:
+                        tree1.media.stop()
+                        tree1.media = vlc.MediaPlayer(tree1.music_list[tree1.music_list_num])
+                        tree1.media.play()   
 
                 if tree1.isloading:
                     tree1.loading(stdscr, maxx)
